==> connector-service-1.0.0-zds-20220408.103834-19-sources.jar: com/bizvane/connectorservice/entity/zds/ZdsCouponDefinition.java <==
package com.bizvane.connectorservice.entity.zds;

import java.math.BigDecimal;
import java.util.Date;

public class ZdsCouponDefinition {

    //线下券类型号
    private String erpCouponDefinitionCode;
    //冗余字段,等于线下券类型号
    private String couponDefinitionId;
    //券名称
    private String couponName;
    //优惠券类型（1现金，2折扣，3兑换）
    private Byte preferentialType;
    //券的面额
    private BigDecimal money;
    //券的折扣
    private BigDecimal discount;
    //有效期类型：(1-时间区间，2-领取后X天内有效)
    private Byte validType;
    //有效期开始时间
    private Date validDateStart;
    //有效期结束时间
    private Date validDateEnd;
    //有效天数
    private Integer validDay;
    //券备注
    private String remark;
    //适用门店
    private String storeWhitelist;
    //适用商品
    private String commodityWhitelist;
    //商品数量最低限制
    private Integer minCommodityNum;
    //最低消费金额
    private BigDecimal minConsume;
    //数据有效性（1有效，0无效）
    private String valid;

    public String getErpCouponDefinitionCode() {
        return erpCouponDefinitionCode;
    }

    public void setErpCouponDefinitionCode(String erpCouponDefinitionCode) {
        this.erpCouponDefinitionCode = erpCouponDefinitionCode;
    }

    public String getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(String couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Byte getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(Byte preferentialType) {
        this.preferentialType = preferentialType;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public Byte getValidType() {
        return validType;
    }

    public void setValidType(Byte validType) {
        this.validType = validType;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Integer getValidDay() {
        return validDay;
    }

    public void setValidDay(Integer validDay) {
        this.validDay = validDay;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getStoreWhitelist() {
        return storeWhitelist;
    }

    public void setStoreWhitelist(String storeWhitelist) {
        this.storeWhitelist = storeWhitelist;
    }

    public String getCommodityWhitelist() {
        return commodityWhitelist;
    }

    public void setCommodityWhitelist(String commodityWhitelist) {
        this.commodityWhitelist = commodityWhitelist;
    }

    public Integer getMinCommodityNum() {
        return minCommodityNum;
    }

    public void setMinCommodityNum(Integer minCommodityNum) {
        this.minCommodityNum = minCommodityNum;
    }

    public BigDecimal getMinConsume() {
        return minConsume;
    }

    public void setMinConsume(BigDecimal minConsume) {
        this.minConsume = minConsume;
    }

    public String getValid() {
        return valid;
    }

    public void setValid(String valid) {
        this.valid = valid;
    }
}

==> connector-service-1.0.2-zds-20220713.084230-4-sources.jar: com/bizvane/connectorservice/entity/zds/ZdsCouponDefinition.java <==
package com.bizvane.connectorservice.entity.zds;

import java.math.BigDecimal;
import java.util.Date;

public class ZdsCouponDefinition {

    //线下券类型号
    private String erpCouponDefinitionCode;
    //冗余字段,等于线下券类型号
    private String couponDefinitionId;
    //券名称
    private String couponName;
    //优惠券类型（1现金，2折扣，3兑换）
    private Byte preferentialType;
    //券的面额
    private BigDecimal money;
    //券的折扣
    private BigDecimal discount;
    //有效期类型：(1-时间区间，2-领取后X天内有效)
    private Byte validType;
    //有效期开始时间
    private Date validDateStart;
    //有效期结束时间
    private Date validDateEnd;
    //有效天数
    private Integer validDay;
    //券备注
    private String remark;
    //适用门店
    private String storeWhitelist;
    //适用商品
    private String commodityWhitelist;
    //商品数量最低限制
    private Integer minCommodityNum;
    //最低消费金额
    private BigDecimal minConsume;
    //数据有效性（1有效，0无效）
    private String valid;
    //券使用说明
    private String rules;

    public String getErpCouponDefinitionCode() {
        return erpCouponDefinitionCode;
    }

    public void setErpCouponDefinitionCode(String erpCouponDefinitionCode) {
        this.erpCouponDefinitionCode = erpCouponDefinitionCode;
    }

    public String getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(String couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Byte getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(Byte preferentialType) {
        this.preferentialType = preferentialType;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public Byte getValidType() {
        return validType;
    }

    public void setValidType(Byte validType) {
        this.validType = validType;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Integer getValidDay() {
        return validDay;
    }

    public void setValidDay(Integer validDay) {
        this.validDay = validDay;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getStoreWhitelist() {
        return storeWhitelist;
    }

    public void setStoreWhitelist(String storeWhitelist) {
        this.storeWhitelist = storeWhitelist;
    }

    public String getCommodityWhitelist() {
        return commodityWhitelist;
    }

    public void setCommodityWhitelist(String commodityWhitelist) {
        this.commodityWhitelist = commodityWhitelist;
    }

    public Integer getMinCommodityNum() {
        return minCommodityNum;
    }

    public void setMinCommodityNum(Integer minCommodityNum) {
        this.minCommodityNum = minCommodityNum;
    }

    public BigDecimal getMinConsume() {
        return minConsume;
    }

    public void setMinConsume(BigDecimal minConsume) {
        this.minConsume = minConsume;
    }

    public String getValid() {
        return valid;
    }

    public void setValid(String valid) {
        this.valid = valid;
    }

    public String getRules() {
        return rules;
    }

    public void setRules(String rules) {
        this.rules = rules;
    }
}
